==> neo4j-kernel-3.1.7-sources.jar: org/neo4j/kernel/impl/api/KernelTransactionMonitorScheduler.java <==
/*
 * Copyright (c) 2002-2017 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.impl.api;

import java.util.concurrent.TimeUnit;

import org.neo4j.kernel.impl.util.JobScheduler;
import org.neo4j.kernel.lifecycle.LifecycleAdapter;

import static org.neo4j.kernel.impl.util.JobScheduler.Groups.transactionTimeoutMonitor;

public class KernelTransactionMonitorScheduler extends LifecycleAdapter
{
    private final KernelTransactionTimeoutMonitor kernelTransactionTimeoutMonitor;
    private final JobScheduler scheduler;
    private final long checkIntervalMillis;
    private JobScheduler.JobHandle monitorJobHandle;

    public KernelTransactionMonitorScheduler( KernelTransactionTimeoutMonitor kernelTransactionTimeoutMonitor,
            JobScheduler scheduler, long checkIntervalMillis )
    {
        this.kernelTransactionTimeoutMonitor = kernelTransactionTimeoutMonitor;
        this.scheduler = scheduler;
        this.checkIntervalMillis = checkIntervalMillis;
    }

    @Override
    public void start() throws Throwable
    {
        if (checkIntervalMillis > 0)
        {
            monitorJobHandle = scheduler.scheduleRecurring( transactionTimeoutMonitor, kernelTransactionTimeoutMonitor,
                    checkIntervalMillis, TimeUnit.MILLISECONDS );
        }
    }

    @Override
    public void stop() throws Throwable
    {
        if ( monitorJobHandle != null )
        {
            monitorJobHandle.cancel( true );
        }
    }
}

==> neo4j-kernel-3.3.0-sources.jar: org/neo4j/kernel/impl/api/KernelTransactionMonitorScheduler.java <==
/*
 * Copyright (c) 2002-2017 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.impl.api;

import java.util.concurrent.TimeUnit;

import org.neo4j.kernel.lifecycle.LifecycleAdapter;
import org.neo4j.scheduler.JobScheduler;

import static org.neo4j.scheduler.JobScheduler.Groups.transactionTimeoutMonitor;

public class KernelTransactionMonitorScheduler extends LifecycleAdapter
{
    private final KernelTransactionTimeoutMonitor kernelTransactionTimeoutMonitor;
    private final JobScheduler scheduler;
    private final long checkIntervalMillis;
    private JobScheduler.JobHandle monitorJobHandle;

    public KernelTransactionMonitorScheduler( KernelTransactionTimeoutMonitor kernelTransactionTimeoutMonitor,
            JobScheduler scheduler, long checkIntervalMillis )
    {
        this.kernelTransactionTimeoutMonitor = kernelTransactionTimeoutMonitor;
        this.scheduler = scheduler;
        this.checkIntervalMillis = checkIntervalMillis;
    }

    @Override
    public void start() throws Throwable
    {
        if ( checkIntervalMillis > 0 )
        {
            monitorJobHandle = scheduler.scheduleRecurring( transactionTimeoutMonitor, kernelTransactionTimeoutMonitor,
                    checkIntervalMillis, TimeUnit.MILLISECONDS );
        }
    }

    @Override
    public void stop() throws Throwable
    {
        if ( monitorJobHandle != null )
        {
            monitorJobHandle.cancel( true );
        }
    }
}
